@@ -235,6 +235,9 @@ class UpdateManager(Gtk.Window):
         self._look_busy()
         self.refresh_cache()
 
+        if self.cache is None:
+            return
+
         pane = self._make_available_pane(self.cache.install_count
                                          + self.cache.del_count,
                                          os.path.exists(REBOOT_REQUIRED_FILE),
@@ -376,7 +379,8 @@ class UpdateManager(Gtk.Window):
                      "Please use the package manager \"Synaptic\" or run "
                      "\"sudo apt-get install -f\" in a terminal to fix "
                      "this issue at first.")
-            self.start_error(True, header, desc)
+            self.start_error(False, header, desc)
+            return
         except SystemError as e:
             header = _("Could not initialize the package information")
             desc = _("An unresolvable problem occurred while "
@@ -384,7 +388,8 @@ class UpdateManager(Gtk.Window):
                      "Please report this bug against the 'update-manager' "
                      "package and include the following error "
                      "message:\n") + str(e)
-            self.start_error(True, header, desc)
+            self.start_error(False, header, desc)
+            return
 
         # Let the Gtk event loop breath if it hasn't had a chance.
         def iterate():
